@@ -1,14 +1,16 @@
+from layout.LayoutObject import LayoutObject
 from config.DisplayConfigger import DisplayConfigger
 from config.StateSaver import DefaultStateSaver
 from DisplayTarget import DisplayTarget
 from TargetGroup import TargetGroup
+from MenuItem import MenuItem
 from main import UNSET_COORD
 from scripting.Script import Script
 from scripting.Scriptlet import Scriptlet
 from utils import actionparser
 from utils.Struct import Struct
 from utils.Observable import Observable
-from utils import Unit
+from layout import Unit
 from utils import vfs
 import utils
 
@@ -22,8 +24,17 @@ import sys
 import os
 import re
 
+#utils.cimport("utils.tiling", "Tiling")
+try:
+    from utils.tiling import Tiling
+except ImportError:
+    import sys
+    log("Could not import tiling module!")
+    sys.exit(1)
+
 
 # The name of the namespace where all display element are accessible.
+
 _ROOT = "Dsp"
 
 
@@ -32,11 +43,11 @@ _ROOT = "Dsp"
 #
 class Display(gtk.HBox, Observable):
 
-    __slots__ = ('__sensor_controls', '__arrays', '__sensor_menu',
+    __slots__ = ('__sensor_controls', '__arrays',
                  '__group', '__script',
                  '__configurator', '__path', '__display_file', '__id',
                  '__last_pointer_pos', '__pointer_pos', '__is_sensitive',
-                 '__menu')
+                 '__cursor_stack')
 
     # observer commands
     OBS_CLOSE = 0
@@ -46,7 +57,9 @@ class Display(gtk.HBox, Observable):
     OBS_TITLE = 4
     OBS_ICON = 5
     OBS_FLAGS = 6
-    OBS_CLOSED = 7
+    OBS_BORDERS = 7
+    OBS_CURSOR = 8
+    OBS_CLOSED = 9
 
 
     # event types
@@ -64,16 +77,29 @@ class Display(gtk.HBox, Observable):
 
     def __init__(self, ident, rep):
 
+        self.__action_stamp = 1
+
         # the display menu
         self.__DISPLAY_MENU = [
-            (_("_Configure desklet"), self.__handle_configure),
-            (_("_Move desklet"), self.__handle_move),
-            ("", None),
-            (_("_View Source"), self.__handle_source),
-            ("", None),
-            (_("Re_start desklet"), self.__handle_restart),
-            (_("_Remove desklet"), self.__handle_remove)]
+            MenuItem("/__cfg", _("_Configure desklet"),
+                     callback = self.__handle_configure),
+            MenuItem("/__move", _("_Move desklet"),
+                     callback = self.__handle_move),
+            MenuItem("/__sep1"),
+            MenuItem("/__src", _("_View Source"),
+                     callback = self.__handle_source),
+            MenuItem("/__sep2"),
+            MenuItem("/__restart", _("Re_start desklet"),
+                     callback = self.__handle_restart),
+            MenuItem("/__remove", _("_Remove desklet"),
+                     callback = self.__handle_remove)
+            ]
 
+        # the layout object
+        self.__layout_object = LayoutObject(None)
+
+        # the stack of current mouse cursors
+        self.__cursor_stack = []
 
         # the controls handling the deprecated sensor stuff: id -> control
         self.__sensor_controls = {}
@@ -81,10 +107,6 @@ class Display(gtk.HBox, Observable):
         # mapping of the elements to their parent arrays: child_id -> array_id
         self.__arrays = {}
 
-        # the deprecated sensor menu
-        # FIXME: remove eventually
-        self.__sensor_menu = []
-
         # content of this display (valid until display has been initialized)
         self.__content = None
 
@@ -123,8 +145,6 @@ class Display(gtk.HBox, Observable):
         # whether the display reacts on events
         self.__is_sensitive = True
 
-        # the menu to open
-        self.__menu = None
 
         gtk.HBox.__init__(self)
 
@@ -158,6 +178,11 @@ class Display(gtk.HBox, Observable):
         if (x != UNSET_COORD): settings["x"] = x
         if (y != UNSET_COORD): settings["y"] = y
 
+        # setup the root layout object (representing the root window)
+        self.__layout_object.set_geometry(Unit.ZERO, Unit.ZERO,
+                              Unit.Unit(gtk.gdk.screen_width(), Unit.UNIT_PX),
+                              Unit.Unit(gtk.gdk.screen_height(), Unit.UNIT_PX))
+
         # build widget hierarchy
         self.new_child(childtype, settings, children)
         self.add(self.__group.get_widget())
@@ -169,6 +194,8 @@ class Display(gtk.HBox, Observable):
         # load stored configuration
         self.__configurator.load_config()
 
+        # unlock the geometry engine
+        gobject.idle_add(self.__group.unlock_geometry)
 
 
     #
@@ -200,7 +227,6 @@ class Display(gtk.HBox, Observable):
     def add_scriptlet(self, code, filename):
 
         scriptlet = Scriptlet(code, filename)
-        #self.execute_script(scriptlet)
         self.__scriptlets.append(scriptlet)
 
 
@@ -260,16 +286,18 @@ class Display(gtk.HBox, Observable):
         w, h = self.__group.get_widget().size_request()
         lx, ly = self.__pointer_pos
 
+        self.__action_stamp += 1
+        actions = []
 
         if (etype == self.EVENT_MOTION):
             x, y = args
 
-            utils.request_call(self.__queue_motion, x, y, w, h, False)
+            utils.request_idle_call(self.__queue_motion, x, y, w, h, False)
             return
 
 
         elif (etype == self.EVENT_LEAVE):
-            utils.request_call(self.__queue_motion, 0, 0, w, h, True)
+            utils.request_idle_call(self.__queue_motion, 0, 0, w, h, True)
             return
 
 
@@ -283,6 +311,7 @@ class Display(gtk.HBox, Observable):
                 action = DisplayTarget.ACTION_DOUBLECLICK
 
             event = Struct(button = button, _args = [button])
+            actions.append((action, event))
 
 
         elif (etype == self.EVENT_RELEASE):
@@ -291,8 +320,11 @@ class Display(gtk.HBox, Observable):
             if (button == 1):
                 if (abs(lx - x) < 10 and abs(ly - y) < 10):
                     action = DisplayTarget.ACTION_CLICK
-                else:
-                    action = DisplayTarget.ACTION_RELEASE
+                    event = Struct(button = button, _args = [button])
+                    actions.append((action, event))
+
+                action = DisplayTarget.ACTION_RELEASE
+
             elif (button == 2):
                 return
             elif (button == 3):
@@ -300,6 +332,7 @@ class Display(gtk.HBox, Observable):
             else:
                 return
             event = Struct(button = button, _args = [button])
+            actions.append((action, event))
 
 
         elif (etype == self.EVENT_SCROLL):
@@ -313,43 +346,37 @@ class Display(gtk.HBox, Observable):
                 direction = -1
             action = DisplayTarget.ACTION_SCROLL
             event = Struct(direction = direction, _args = [direction])
+            actions.append((action, event))
 
 
         elif (etype == self.EVENT_KEY_PRESS):
             key, x, y = args
             action = DisplayTarget.ACTION_KEY_PRESS
             event = Struct(key = key)
+            actions.append((action, event))
 
 
         elif (etype == self.EVENT_KEY_RELEASE):
             key, x, y = args
             action = DisplayTarget.ACTION_KEY_RELEASE
             event = Struct(key = key)
+            actions.append((action, event))
 
 
         else:
             # what kind of event did we get there?
             assert (False)  # never reached
 
-        self.__group.handle_action(action,
-                                   Unit.Unit(x, Unit.UNIT_PX),
-                                   Unit.Unit(y, Unit.UNIT_PX),
-                                   event)
-        self.__group.notify_handle_action(True)
+        for action, event in actions:
+            self.__group.get_layout_object().send_action(
+                Unit.Unit(x, Unit.UNIT_PX),
+                Unit.Unit(y, Unit.UNIT_PX),
+                self.__action_stamp,
+                action, event)
 
         # extend the menu or create one if there's none
         if (action == DisplayTarget.ACTION_MENU):
-            self.__make_menu(0, 0)
-
-
-
-    #
-    # Sets the sensitive flag of the display. Insensitive displays don't react
-    # on user events.
-    #
-    def set_sensitive(self, value):
-
-        self.__is_sensitive = value
+            utils.request_idle_call(self.open_menu, [])
 
 
 
@@ -384,6 +411,16 @@ class Display(gtk.HBox, Observable):
 
 
 
+    #
+    # Creates and returns a new layout object as a child of this element's
+    # layout object.
+    #
+    def new_layout_object(self):
+
+        return self.__layout_object.new_child()
+
+
+
     def new_child(self, childtype, settings, children):
 
         import targetregistry
@@ -391,7 +428,7 @@ class Display(gtk.HBox, Observable):
         try:
             self.__group = targetregistry.create(childtype, self)
         except KeyError, exc:
-            log(exc)
+            log(`exc`)
         self.__group.get_widget().show()
         cid = settings["id"]
         self.add_target_to_script(cid, self.__group)
@@ -504,81 +541,12 @@ class Display(gtk.HBox, Observable):
                 self.call_sensor(legacy_call, path, *legacy_args)
 
             else:
-                src.notify_handle_action(True)
+                #src.notify_handle_action(True)
                 src._setp("event", event)
                 self.execute_callback_script(call, src)
 
 
 
-    #
-    # Has to be called when a menu is to open. Do not open the menu yourself.
-    #
-    def queue_menu(self, menu):
-
-        self.__menu = menu
-
-
-
-    #
-    # Builds the menu.
-    #
-    def __make_menu(self, button, eventtime):
-
-        need_separator = False
-        if (not self.__menu):
-            ident = Display.make_id()
-            self.__menu = self.__group.new_child("menu",
-                                                 {"id": ident},
-                                                 [])
-            self.__group.set_prop("on-menu", "%s.%s.popup()" % (_ROOT, ident))
-
-        elif (not "display" in self.__menu.get_slots()):
-            # add separator
-            need_separator = True
-        #end if
-
-        # FIXME: remove eventually :)
-        if (self.__sensor_menu and
-            not "deprecated sensor menu" in self.__menu.get_slots()):
-            for entry in self.__sensor_menu:
-                if (not entry):
-                    label, active, submenu, h, args = \
-                           "", True, None, None, []
-                else:
-                    label, active, submenu, h, args = entry
-
-                item = self.__menu.new_child("menu-item",
-                                             {"id": Display.make_id(),
-                                              "slot": "deprecated sensor menu",
-                                              "label": label},
-                                             [])
-                args = [item.get_widget()] + list(args)
-                if (h): item.set_handler(h, *args)
-                if (not active): item.set_prop("active", False)
-        #end if
-
-        if (not "display" in self.__menu.get_slots()):
-            if (need_separator):
-                self.__menu.new_child("menu-item",
-                                      {"id": Display.make_id(),
-                                       "slot": "display"}, [])
-
-            for label, h in self.__DISPLAY_MENU:
-                item = self.__menu.new_child("menu-item",
-                                             {"id": Display.make_id(),
-                                              "slot": "display",
-                                              "label": label},
-                                             [])
-                if (h): item.set_handler(h)
-        #end if
-
-        self.__menu.prepare()
-        self.__menu.get_widget().popup(None, None, None, button,
-                                       eventtime)
-        self.__menu = None
-
-
-
     def __queue_motion(self, px, py, w, h, is_leave):
 
         # some window managers send a LEAVE event for mouse clicks;
@@ -594,11 +562,18 @@ class Display(gtk.HBox, Observable):
         if (not is_leave):
             ux = Unit.Unit(px, Unit.UNIT_PX)
             uy = Unit.Unit(py, Unit.UNIT_PX)
-            self.__group.handle_action(DisplayTarget.ACTION_MOTION,
-                                       ux, uy, Struct())
-            self.__group.notify_handle_action(True)
+            self.__group.get_layout_object().send_action(ux, uy,
+                                                         self.__action_stamp,
+                                                   DisplayTarget.ACTION_MOTION,
+                                                         Struct())
+            #self.__group.handle_action(DisplayTarget.ACTION_MOTION,
+            #                           ux, uy, Struct())
+            #self.__group.notify_handle_action(True)
+            self.__group.detect_leave(self.__action_stamp)
+            #self.__action_stamp += 1
         else:
-            self.__group.notify_handle_action(False)
+            self.__group.detect_leave(self.__action_stamp)
+            #self.__group.notify_handle_action(False)
 
 
 
@@ -608,16 +583,17 @@ class Display(gtk.HBox, Observable):
     def child_observer(self, src, cmd):
 
         if (cmd == src.OBS_GEOMETRY):
+            #src.get_layout_object().dump()
             x, y, w, h = self.__group.get_geometry()
             ux, uy = self.__group.get_user_geometry()[:2]
 
             if (ux.is_unset() or uy.is_unset()):
-                utils.request_call(self.update_observer, self.OBS_GEOMETRY,
+                utils.request_idle_call(self.update_observer, self.OBS_GEOMETRY,
                                    UNSET_COORD, UNSET_COORD,
                                    w.as_px(), h.as_px())
             else:
                 self.__save_position()
-                utils.request_call(self.update_observer, self.OBS_GEOMETRY,
+                utils.request_idle_call(self.update_observer, self.OBS_GEOMETRY,
                                    x.as_px(), y.as_px(),
                                    w.as_px(), h.as_px())
 
@@ -639,8 +615,9 @@ class Display(gtk.HBox, Observable):
                 new_x = x.as_px() + dx.as_px()
                 new_y = y.as_px() + dy.as_px()
 
-                self.__group.set_xml_prop("x", str(new_x))
-                self.__group.set_xml_prop("y", str(new_y))
+                #sx, sy = self.__layout_object.get_scaling()
+                self.__group.set_xml_prop("x", str(new_x))# / sx))
+                self.__group.set_xml_prop("y", str(new_y))# / sy))
 
 
 
@@ -689,6 +666,9 @@ class Display(gtk.HBox, Observable):
         if (key == "window-flags"):
             self.update_observer(self.OBS_FLAGS, value)
 
+        elif (key == "desktop-borders"):
+            self.update_observer(self.OBS_BORDERS, value)
+
         elif (key == "title"):
             self.update_observer(self.OBS_TITLE, value)
 
@@ -712,7 +692,11 @@ class Display(gtk.HBox, Observable):
         elif (key == "shape"):
             if (value.lstrip().startswith("<")):
                 from utils.DOM import DOM
-                from utils import svg
+                try:
+                    from utils import svg
+                except ImportError:
+                    log("Could not import svg module!")
+                    return
                 w, h, = self.size_request()
                 if (not w or not h): return
                 root = DOM(value).get_root()
@@ -743,13 +727,66 @@ class Display(gtk.HBox, Observable):
 
 
 
+    #
+    # Changes the mouse cursor.
+    #
+    def __set_cursor(self):
+
+        if (self.__cursor_stack):
+            cursor = self.__cursor_stack[-1]
+        else:
+            cursor = None
+
+        self.update_observer(self.OBS_CURSOR, cursor)
+
+
+
+    #
+    # Adds a cursor to the cursor stack.
+    #
+    def push_cursor(self, cursor):
+
+        self.__cursor_stack.append(cursor.upper())
+        utils.request_call(self.__set_cursor)
+
+
+
+    #
+    # Removes a cursor from the cursor stack.
+    #
+    def pop_cursor(self, cursor):
+
+        try:
+            self.__cursor_stack.remove(cursor.upper())
+        except:
+            pass
+        utils.request_call(self.__set_cursor)
+
+
+
     #
     # Adds a sensor to this display.
     # FIXME: remove eventually :)
     #
     def add_sensor(self, ident, sensor):
 
-        def set_menu(menu): self.__sensor_menu = menu
+        def set_menu(menu):
+
+            m = []
+            cnt = 0
+            for entry in menu[:-1]:
+                if (not entry):
+                    m.append(MenuItem("/sep%d" % cnt))
+                else:
+                    callback = entry[3]
+                    args = [None] + list(entry[4])
+                    m.append(MenuItem("/item%d" % cnt, entry[0], None,
+                                      callback, args))
+                cnt += 1
+            #end for
+
+            utils.request_call(self.open_menu, m)
+
 
         self.__sensor_controls[ident] = sensor
         sensor.bind("output", self.__set_settings, ident)
@@ -838,6 +875,68 @@ class Display(gtk.HBox, Observable):
 
 
 
+    #
+    # Opens a menu.
+    #
+    def open_menu(self, menu):
+
+        # always work on a copy
+        menu = menu[:]
+
+        if (menu): menu.append(MenuItem("/__separator"))
+        menu += self.__DISPLAY_MENU
+
+        mainmenu = gtk.Menu()
+        tree = {}
+        for entry in menu:
+            if (not entry.label):
+                item = gtk.SeparatorMenuItem()
+
+            elif (entry.icon):
+                item = gtk.ImageMenuItem(entry.label)
+                try:
+                    img = Tiling()
+                    data = vfs.read_entire_file(self.get_full_path(entry.icon))
+                    img.set_from_data(data)
+                    img.render(16, 16, 1, 1)
+                    img.show()
+                    item.set_image(img)
+                except:
+                    import traceback; traceback.print_exc()
+                    pass
+
+            else:
+                item = gtk.MenuItem(entry.label)
+
+            if (entry.callback):
+                item.connect("activate",
+                             lambda src, cb, args: cb(*args),
+                             entry.callback, entry.args)
+
+            item.show()
+            if (not entry.active): item.set_sensitive(False)
+
+            menupath = "/".join(entry.path.split("/")[:-1])
+            if (menupath):
+                parentitem = tree.get(menupath)
+
+                if (not parentitem.get_submenu()):
+                    m = gtk.Menu()
+                    parentitem.set_submenu(m)
+                else:
+                    m = parentitem.get_submenu()
+
+            else:
+                m = mainmenu
+
+            m.append(item)
+            tree["/".join(entry.path.split("/"))] = item
+        #end for
+
+        mainmenu.popup(None, None, None, 0, 0)
+
+
+
     def __handle_configure(self, *args):
 
         self.__open_configurator()
@@ -883,7 +982,7 @@ class Display(gtk.HBox, Observable):
                               _("Do you really want to remove this desklet ?"),
                               _("This desklet will no longer be displayed "
                                 "and its configuration will be purged."),
-                              (gtk.STOCK_CANCEL, Null),
+                              (gtk.STOCK_CANCEL, None),
                               (gtk.STOCK_DELETE, remove_display)
                              )
 
