@@ -12,8 +12,7 @@ class DisplayConfigurator(HIGDialog):
 
     def __init__(self, sensorconfigurators):
 
-        HIGDialog.__init__(self, None, "", "", (gtk.STOCK_CLOSE,
-                                                gtk.RESPONSE_CLOSE))
+        HIGDialog.__init__(self, buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
         self.set_property("title", _("Configuration"))
 
         def destroy(*args): self.destroy()
@@ -30,7 +29,7 @@ class DisplayConfigurator(HIGDialog):
 
         # use a special page when there are no config options
         if (not pages):
-            lbl = gtk.Label(_("This display is not configurable."))
+            lbl = gtk.Label(_("This desklet is not configurable."))
             lbl.show()
             pages.append((lbl, None))
 
@@ -39,7 +38,6 @@ class DisplayConfigurator(HIGDialog):
             self.vbox.add(pages[0][0])
         else:
             align = gtk.Alignment(0.0, 0.0, 0.0, 0.0)
-            #align.set_property("right-padding", 2)
             align.show()
             notebook = gtk.Notebook()
             notebook.set_property("border-width", 6)
