@@ -1,16 +1,18 @@
 from config import settings
 from utils import wallpaper
 from utils.BGWatcher import BGWatcher
-
-try:
-    from utils import ewmh
-except ImportError:
-    log("Couldn't load EWMH support. Some window flags won't work.")
-    ewmh = Null
+from utils.tiling import Tiling
 
 import gobject
 import gtk
 
+try:
+    from utils import x11
+except ImportError:
+    import sys
+    log("Could not import x11 module!")
+    sys.exit(1)
+
 _BGWATCHER = BGWatcher()
 
 _MOOSE_DELAY = 100
@@ -38,9 +40,6 @@ class GlassWindow(gtk.Window):
         # handler for transparency updates
         self.__update_handler = None
 
-        # the desktop background
-        self.__bg_root = None
-
         # remember the current window position to detect movements
         self.__position = (0, 0)
         self.__size = (0, 0)
@@ -53,18 +52,25 @@ class GlassWindow(gtk.Window):
         if (settings.translucent and _TRANSLUCENT_CMAP):
             gtk.widget_pop_colormap()
 
+        self.__layout = gtk.Fixed()
+        self.__layout.show()
+        gtk.Window.add(self, self.__layout)
+
         # welcome to the future!
         if (not settings.translucent and not HAVE_WIN32):
             # mommy, my xserver doesn't have translucency... :(
-            self.connect("configure-event", self.__on_configure)
-            _BGWATCHER.add_observer(self.__bg_observer)
+            self.__background = Tiling()
+            self.__background.show()
+            self.__layout.put(self.__background, 0, 0)
 
-            self.__bg_image = gtk.gdk.Pixbuf(0, 1, 8, 10, 10)
-            self.__bg_image.fill(0xffffff)
+            self.connect("configure-event", self.__on_configure)
+
+            _BGWATCHER.add_observer(self.__bg_observer)
 
         else:
             # real men don't need wimpy pseudo-transparency... 8)
-            self.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("#000000"))
+            self.modify_bg(gtk.STATE_NORMAL,
+                           gtk.gdk.color_parse("#000000"))
 
             if (HAVE_WIN32):
                 import win32gui
@@ -82,6 +88,23 @@ class GlassWindow(gtk.Window):
                                                     0x0a0a0a, 0xff,
                                                     LWA_COLORKEY)
 
+    #
+    # Override add method.
+    #
+    def add(self, widget):
+
+        self.__layout.put(widget, 0, 0)
+
+
+
+    #
+    # Override resize method.
+    #
+    def resize(self, width, height):
+
+        self.__layout.set_size_request(width, height)
+        gobject.idle_add(gtk.Window.resize, self, width, height)
+
 
 
     #
@@ -123,7 +146,7 @@ class GlassWindow(gtk.Window):
     #
     def __capture_bg(self, x, y, width, height):
 
-        wallpaper.get_wallpaper(self, x, y, width, height)
+        wallpaper.get_wallpaper(self.__background, x, y, width, height)
         self.queue_draw()
 
 
@@ -145,29 +168,31 @@ class GlassWindow(gtk.Window):
     #
     # Sets the BELOW window flag.
     #
-    def _set_flag_below(self, value):
+    def _set_flag_below(self, value, tries = 0):
 
         if (not self.__get_window_manager() in ["Enlightenment"] and
-            not self.get_property("visible")):
-            gobject.timeout_add(500, self._set_flag_below, value)
+            not self.get_property("visible") and tries < 10):
+            gobject.timeout_add(500, self._set_flag_below, value, tries + 1)
 
-        ewmh.set_above(self.window, not value)
-        ewmh.set_below(self.window, value)
+        if (self.window):
+            x11.set_above(self.window, not value)
+            x11.set_below(self.window, value)
 
 
 
     #
     # Sets the ABOVE window flag.
     #
-    def _set_flag_above(self, value):
+    def _set_flag_above(self, value, tries = 0):
 
         if (not self.__get_window_manager() in ["Enlightenment"] and
             not self.__get_window_manager().startswith("Xfwm4") and
-            not self.get_property("visible")):
-            gobject.timeout_add(500, self._set_flag_above, value)
+            not self.get_property("visible") and tries < 10):
+            gobject.timeout_add(500, self._set_flag_above, value, tries + 1)
 
-        ewmh.set_below(self.window, not value)
-        ewmh.set_above(self.window, value)
+        if (self.window):
+            x11.set_below(self.window, not value)
+            x11.set_above(self.window, value)
 
 
 
@@ -181,6 +206,12 @@ class GlassWindow(gtk.Window):
 
 
 
+    def _set_type_hint_dock(self, window, value):
+
+        x11.set_type_dock(window, value)
+
+
+
     #
     # Sets the MANAGED window flag.
     #
@@ -189,13 +220,12 @@ class GlassWindow(gtk.Window):
         if (value):
             self.set_property("skip-taskbar-hint", 0)
             self.set_property("skip-pager-hint", 0)
-            ewmh.set_type_dock(self.window, False)
+            self._set_type_hint_dock(self.window, False)
         else:
             self.set_property("skip-taskbar-hint", 1)
             self.set_property("skip-pager-hint", 1)
             wm = self.__get_window_manager()
-            if (wm == "Metacity"):
-                ewmh.set_type_dock(self.window, True)
+            if (wm == "Metacity"): self._set_type_hint_dock(self.window, True)
 
 
 
@@ -230,16 +260,16 @@ class GlassWindow(gtk.Window):
         return name
 
 
-
 if (not HAVE_WIN32):
     # get the window where the EMWH compliant window manager tells its name
     root = gtk.gdk.get_default_root_window()
 
     try:
         ident = root.property_get("_NET_SUPPORTING_WM_CHECK", "WINDOW")[2]
+        _WM_NAME_WIN = gtk.gdk.window_foreign_new(long(ident[0]))
     except TypeError, exc:
+        _WM_NAME_WIN = ""
         log("Your window manager doesn't support "
             "_NET_SUPPORTING_WM_CHECK! Switch to a compliant WM!"
             "The following error occured:\n%s" % (exc,))
 
-    _WM_NAME_WIN = gtk.gdk.window_foreign_new(long(ident[0]))
