@@ -1,14 +1,19 @@
 from DisplayTarget import DisplayTarget
-from utils.DOM import DOM
-from utils import svg
-from utils.datatypes import *
 from layout import Unit
+from utils.DOM import DOM
+from utils.datatypes import *
 from utils import dialog
 from utils import vfs
 import utils
 
 import gtk
 
+try:
+    from utils import svg
+except ImportError:
+    import sys
+    log("Could not import svg module!")
+    sys.exit(1)
 
 
 #
@@ -31,7 +36,6 @@ class TargetCanvas(DisplayTarget):
         DisplayTarget.__init__(self, name, parent)
 
         self.__widget = gtk.Image()
-        #self.__widget.connect("expose-event", self.__on_expose)
         self.__widget.show()
 
         # the "graphics" property is not readable because otherwise it could
@@ -54,6 +58,7 @@ class TargetCanvas(DisplayTarget):
     def get_widget(self): return self.__widget
 
 
+
     def delete(self):
 
         del self.__dom
@@ -74,7 +79,6 @@ class TargetCanvas(DisplayTarget):
             self.__old_size = (w.as_px(), h.as_px())
 
 
-        
 
     #
     # Transforms the given coordinates into buffer space.
@@ -180,7 +184,7 @@ class TargetCanvas(DisplayTarget):
                 pass
 
         self.__redraw()
-        
+
 
     #
     # Redraws the canvas.
@@ -191,7 +195,7 @@ class TargetCanvas(DisplayTarget):
 
         w, h = self.__widget.size_request()
         imgw, imgh = self.__image_size
-        
+
         # crappy SVG needs the size to be given; just set it here so that it
         # dynamically takes the correct size
         self.__dom["width"] = str(w or 100)
