@@ -1,6 +1,4 @@
 from ContainerTarget import ContainerTarget
-#from utils.TilingImage import TilingImage
-from utils.tiling import Tiling as TilingImage
 from utils.datatypes import *
 from layout import Unit
 from utils import vfs
@@ -9,6 +7,13 @@ import utils
 import os
 import gtk
 
+try:
+    from utils.tiling import Tiling
+except ImportError:
+    import sys
+    log("Could not import tiling module!")
+    sys.exit(1)
+
 
 #
 # Class for putting frames around targets.
@@ -31,7 +36,7 @@ class TargetFrame(ContainerTarget):
         r, g, b, a = utils.parse_color("black")
         for x, y in [(0, 1), (1, 0), (2, 1), (1, 2),
                      (0, 0), (2, 0), (2, 2), (0, 2)]:
-            img = TilingImage()
+            img = Tiling()
             img.set_from_color(r, g, b, a)
             img.show()
             self.__table.attach(img, x, x + 1, y, y + 1)
