@@ -1,11 +1,17 @@
 from ContainerTarget import ContainerTarget
-from utils.tiling import Tiling as TilingImage
 from utils.datatypes import *
 import utils
 
 import gtk
 import os
 
+try:
+    from utils.tiling import Tiling
+except ImportError:
+    import sys
+    log("Could not import tiling module!")
+    sys.exit(1)
+
 
 #
 # Class for grouping different targets together.
@@ -24,7 +30,7 @@ class TargetGroup(ContainerTarget):
         self.__layout = gtk.Fixed()
         self.__layout.show()
 
-        self.__image = TilingImage()
+        self.__image = Tiling()
         self.__image.show()
         self.__layout.put(self.__image, 0, 0)
 
