@@ -2,11 +2,17 @@ from DisplayTarget import DisplayTarget
 from utils.datatypes import *
 from layout import Unit
 from utils import vfs
-from utils.tiling import Tiling
 import utils
 
 import gtk
 
+try:
+    from utils.tiling import Tiling
+except ImportError:
+    import sys
+    log("Could not import tiling module!")
+    sys.exit(1)
+
 
 #
 # Class for image targets.
