@@ -19,7 +19,6 @@ class TargetPlotter(TargetCanvas):
         # scale range, initial value
         self.__minscale = 0
         self.__maxscale = 100
-        
 
         TargetCanvas.__init__(self, name, parent)
 
@@ -67,17 +66,19 @@ class TargetPlotter(TargetCanvas):
         delta_x = 100.0 / (size - 1)
 
         if (bg):
+            try:
+                color, opacity = self.__parse_color(bg)
+            except ValueError, exc:
+                log(`exc`)
+                return
+
             body = "<rect x=\"0\" y=\"0\" width=\"100\" height=\"100\" " \
                    "style=\"stroke:%s;stroke-opacity:%d%%;fill:%s;" \
-                   "fill-opacity:%d%%\"/>" % (self.__parse_color(bg),
-                                              self.__parse_color(bg))
+                   "fill-opacity:%d%%\"/>" % (color, opacity, color, opacity)
         else:
             body = ""
 
-        #max_value = 100
         if (self.__history):
-            #max_value = max(100, max(self.__history))
-            #scale = 100.0 / max_value
             if ((self.get_prop("scale-holdmax")) == False):
                 # reset scale range to default:
                 max_value = 100
@@ -89,18 +90,25 @@ class TargetPlotter(TargetCanvas):
             self.__maxscale = max_value
             scale = 100.0 / (max_value - min_value)
 
-            x, y = x, self.__history[0]
+            history_size = min(len(self.__history), size)
+            
+            x, y = x, self.__history[-history_size]
             body += "<path d=\"M%f %f " % (x, 100 - (y - min_value) * scale)
             x += delta_x
 
-        
-            for y in self.__history[1:]:
+            for y in self.__history[-history_size + 1:]:
                 y = 100 - (y - min_value) * scale
                 body += "L%(x)f %(y)f " % vars()
                 x += delta_x
+
+            try:
+                color, opacity = self.__parse_color(fg)
+            except ValueError, exc:
+                log(`exc`)
+                return
+
             body += "\" style=\"stroke:%s;opacity:%d%%;fill:none\"/>" % \
-                    self.__parse_color(fg)
-        #end if
+                     (color, opacity)
 
         # draw scala
         scala = self.get_prop("scala")
@@ -122,8 +130,10 @@ class TargetPlotter(TargetCanvas):
         if ("#" in value and len(value) == 9):
             opacity = float(int(value[7:], 16) / 255.0) * 100
             return (value[:7], opacity)
-        else:
+        elif (value.isalnum()):
             return (value, 100)
+        else:
+            raise ValueError("%s is an invalid color." % `value`)
 
 
 
