@@ -7,6 +7,10 @@ def create_arch():
 
 def __detect_arch():
 
+    if (HAVE_WIN32):
+        import Windows
+        return Windows.Win32()
+
     import os
     uname = os.uname()
 
@@ -47,8 +51,9 @@ def __detect_arch():
         return NetBSD.Generic()
 
 
-    import sys; print >>sys.stderr, "OS/Architecture not found!"
+    log("OS/Architecture not found!")
 
     import Arch
 
     return Arch.Arch()
+
