@@ -34,7 +34,6 @@ class DisplayList:
         # the list of unsaved modifications to the list
         self.__modifications = []
 
-
         self.__load_list()
 
 
@@ -53,13 +52,23 @@ class DisplayList:
         except IOError, exc:
             return
 
-        self.__current_profile = data.pop(0).strip()
+        try:
+            self.__current_profile = data.pop(0).strip()
+        except IndexError, exc:
+            log("The displaylist file has wrong format, ignoring it.")
+            return
+
         self.__profiles[self.__current_profile] = []
 
         for line in data:
-            if (not line):
-                continue
-            ident, path, profile = line.split()
+            if (not line): continue
+
+            try:
+                ident, path, profile = line.split()
+            except ValueError, exc:
+                log("The displaylist file has wrong format, ignoring it.")
+                return
+
             path = vfs.unescape_path(path)
             profile = vfs.unescape_path(profile)
             if (not profile in self.__profiles):
@@ -181,7 +190,7 @@ class DisplayList:
             profile, path = self.lookup_display(ident)
         except KeyError, exc:
             log("The following error occured while removing display \"%s\"!"
-                 % (path, exc))
+                 % exc)
             return
 
         self.__modifications.append((self.__DEL, profile, path, ident))
