@@ -24,6 +24,9 @@ class RemoteSocket:
 
         self.__stopevent = False
 
+        # marks the socket as blocked, i.e. must not accept new requests
+        self.__block_timeout = {}
+
 
 
     def start(self):
@@ -60,7 +63,7 @@ class RemoteSocket:
                     log("Couldn't bind to socket. Aborting.")
                     sys.exit(1)
 
-        serversock.listen(1)
+        serversock.listen(3)
         serversock.setblocking(False)
 
         atexit.register(self.__shutdown, serversock, sockfile)
@@ -106,6 +109,7 @@ class RemoteSocket:
         else:
             # new connection
             cnx.setblocking(False)
+            self.__block_timeout[cnx] = 0
             gobject.timeout_add(250, self.__client_handler, cnx)
 
         return True
@@ -117,6 +121,38 @@ class RemoteSocket:
           The client server reactor. A new client gets its own new reactor.
         """
 
+
+        def callback(*retval):
+
+            self.__block_timeout[clientsock] = 0
+
+            try:
+                xdr.send(clientsock, *retval)
+
+            # hmm, we aren't able to send somthing here
+            except socket.error, exc:
+                log("Socket is dead!\n%s\n" % exc)
+                return False
+
+            # the data seems to be of size zero here
+            except xdr.XDRError, exc:
+                log(`exc`)
+
+            # something really unexpected has happened
+            except:
+                try:
+                    xdr.send_error(clientsock)
+                except:
+                    import traceback; traceback.print_exc()
+
+
+        if (self.__block_timeout[clientsock] > 0):
+            self.__block_timeout[clientsock] -= 1
+
+            if (self.__block_timeout[clientsock] == 0):
+                callback()
+            return True
+
         try:
             data = xdr.recv(clientsock)
 
@@ -126,6 +162,7 @@ class RemoteSocket:
 
         # socket disconnected
         except xdr.XDRError:
+            clientsock.close()
             return False
 
         message = data[0]
@@ -137,9 +174,20 @@ class RemoteSocket:
         # message_handler doesn't exist
         except KeyError:
             log("Key %s doesn't exist in message_handlers!" % (message,))
+            clientsock.close()
             return False
 
+        # timeout after 20 * 250 ms
+        self.__block_timeout[clientsock] = 20
+        handler(callback, *args)
+        return True
+
+        #
+        #
+        #
+
         try:
+            #handler(callback, *args)
             retval = handler(*args)
             if (retval == None): retval = ()
 
@@ -173,4 +221,3 @@ class RemoteSocket:
                 import traceback; traceback.print_exc()
 
         return True
-
