@@ -1,7 +1,6 @@
 import os
 import sys
 import utils
-import NullObject
 import __builtin__
 from utils import vfs
 
@@ -70,8 +69,8 @@ _ = Translator("gdesklets")
 
 
 NAME = "gDesklets"
-VERSION = "0.35.2"
-COPYRIGHT = u"Copyright \xa9 2003 - 2005 The gDesklets Team"
+VERSION = "0.35.3"
+COPYRIGHT = u"Copyright \xa9 2003 - 2006 The gDesklets Team"
 DESCRIPTION = _("A desktop applet system for GNOME")
 AUTHORS = ( "Martin Grimme <martin@pycage.de>",
             "Christian Meyer <chrisime@gnome-de.org>",
@@ -83,7 +82,7 @@ DOCUMENTERS = ("Martin Grimme <martin@pycage.de>",)
 ICON = os.path.join(HOME, "data", "gdesklets.png")
 CREDITS = (
            (_("Version %s") % (VERSION,),
-           (u"Copyright \xa9 2003 - 2005", "The gDesklets Team")),
+           (u"Copyright \xa9 2003 - 2006", "The gDesklets Team")),
 
            (_("Core Programming:"),
            ("Martin Grimme", "Christian Meyer", "Jesse Andrews",
@@ -100,7 +99,7 @@ CREDITS = (
            ("Johannes Rebhan",)),
 
            (_("Website:"),
-           ("Luke Stroven",)),
+           ("Marius M.M.", "Luke Stroven (previous site)",)),
 
            (_("Thank you:"),
            ("VidaLinux for sponsoring",
