@@ -7,6 +7,6 @@ COMMAND_DISPLAYS = "displays"
 COMMAND_DISPLAY_LIST = "display list"
 COMMAND_GEOMETRY = "geometry"
 COMMAND_SET_REMOVE_COMMAND = "set remove command"
-COMMAND_SET_STARTUP_COMMAND = "set startup command"
 COMMAND_VERSION = "version"
 COMMAND_ABOUT = "about"
+COMMAND_CONFIGURE = "configure"
