@@ -56,7 +56,7 @@ class Sensor(Observable):
         self.__stop_flag = False
 
         # when stopping, the flag is set to True, then the callback is called
-        self.__stop_callback = Null
+        self.__stop_callback = None
 
         self.__defaults = {}
 
@@ -317,7 +317,7 @@ class Sensor(Observable):
     def stop(self):
 
         self.__stop_flag = True
-        self.__stop_callback()
+        if (self.__stop_callback): self.__stop_callback()
 
         del self.__config_watcher
         self.__config_manager.remove_watcher(self.get_config_id(),
