@@ -1,8 +1,7 @@
 from Observable import Observable
 import wallpaper
 
-import gtk
-import gconf
+import gobject
 import time
 
 
@@ -15,14 +14,12 @@ class BGWatcher(Observable):
 
     def __init__(self):
 
+        if (HAVE_WIN32): return
+
         self.__old_bg = 0
-        self.__last_update = 0
+        self.__last_update = 0.0
 
-        self.__client = gconf.client_get_default()
-        self.__client.notify_add(wallpaper.GCONF_BACKGROUND,
-                                 self.__notify_gconf)
-
-        gtk.timeout_add(50, self.__check_bg)
+        gobject.timeout_add(50, self.__check_bg)
 
 
 
@@ -31,23 +28,21 @@ class BGWatcher(Observable):
         try:
             ident = wallpaper.get_wallpaper_id()
             if (ident != self.__old_bg):
-                self.__last_update = str(time.time())
-                gtk.timeout_add(500, self.__notify_update, self.__last_update)
+                self.__last_update = time.time()
+                gobject.timeout_add(500, self.__notify_update,
+                                    self.__last_update)
             self.__old_bg = ident
 
         except StandardError:
             if (self.__old_bg):
-                self.__last_update = str(time.time())
-                gtk.timeout_add(500, self.__notify_update, self.__last_update)
+                self.__last_update = time.time()
+                gobject.timeout_add(500, self.__notify_update,
+                                    self.__last_update)
                 self.__old_bg = 0
 
         return True
 
 
-    def __notify_gconf(self, client, cid, entry, err):
-
-        self.__old_bg = 0
-
 
     def __notify_update(self, timestamp):
 
@@ -55,3 +50,4 @@ class BGWatcher(Observable):
         self.update_observer(self.OBS_CHANGE_BG)
 
         return False
+
