@@ -32,10 +32,9 @@ static PyObject* render(PyObject *self, PyObject *args)
   PyObject *string;
   RsvgHandle *handle;
 
-  gboolean success;
-  gchar *buffer;
-  gint32 length;
-  guint32 width, height;
+  char *buffer;
+  int length;
+  int width, height;
 
   if(!PyArg_ParseTuple(args, "O&IIS", parse_gtk_image,
                        &image, &width, &height, &string))
@@ -44,19 +43,24 @@ static PyObject* render(PyObject *self, PyObject *args)
   if(PyString_AsStringAndSize(string, &buffer, &length) == -1)
     return NULL;
 
-  handle = rsvg_handle_new ();
-  success = rsvg_handle_write (handle, (const guchar *)buffer, length, &error);
-  if (!success) {
+  if (!(handle = rsvg_handle_new ())) {
+    g_error("Couldn't create handle!");
+    return NULL;
+  }
+  if (!rsvg_handle_write (handle, (const guchar *)buffer, length, &error)) {
     g_error("Error writing buffer to handle: %s\n", error->message);
   }
-  success = rsvg_handle_close (handle, &error);
-  if (!success) {
+  if (!rsvg_handle_close (handle, &error)) {
     g_error("Error closing handle: %s\n", error->message);
   }
-  pbuf = rsvg_handle_get_pixbuf (handle);
+  if (!(pbuf = rsvg_handle_get_pixbuf (handle))) {
+    g_error("Error creating pixbuf from handle.");
+  }
+  else {
+    gtk_image_set_from_pixbuf (image, pbuf);
+    g_object_unref (G_OBJECT (pbuf));
+  }
   rsvg_handle_free (handle);
-  gtk_image_set_from_pixbuf (image, pbuf);
-  g_object_unref (G_OBJECT (pbuf));
 
   Py_INCREF(Py_None);
   return Py_None;
