@@ -22,6 +22,8 @@
 #include "utils.h"
 
 
+PyMODINIT_FUNC initsystray(void);
+
 typedef struct _Icon Icon;
 
 struct _Icon
@@ -35,12 +37,12 @@ struct _Icon
 
 static int icon_init(PyObject *self, PyObject *args, PyObject *kw)
 {
-  static const char * const kwnames[] = {"name", NULL};
+  static const gchar * const kwnames[] = {"name", NULL};
 
-  const char *name;
+  const gchar *name;
   Icon * const that = (Icon*) self;
 
-  if(!PyArg_ParseTupleAndKeywords(args, kw, "s", (char **) kwnames, &name))
+  if(!PyArg_ParseTupleAndKeywords(args, kw, "s", (gchar **) kwnames, &name))
     return -1;
 
   that->icon = egg_tray_icon_new(name);
@@ -97,48 +99,47 @@ initsystray(void)
   static const PyTypeObject IconType =
     {
       PyObject_HEAD_INIT(NULL)
-      0,                         /*ob_size*/
-      "systray.Icon",     /*tp_name*/
-      sizeof(Icon),       /*tp_basicsize*/
-      0,                         /*tp_itemsize*/
-      icon_dealloc,       /*tp_dealloc*/
-      0,                         /*tp_print*/
-      0,                         /*tp_getattr*/
-      0,                         /*tp_setattr*/
-      0,                         /*tp_compare*/
-      0,                         /*tp_repr*/
-      0,                         /*tp_as_number*/
-      0,                         /*tp_as_sequence*/
-      0,                         /*tp_as_mapping*/
-      0,                         /*tp_hash */
-      0,                         /*tp_call*/
-      0,                         /*tp_str*/
-      0,                         /*tp_getattro*/
-      0,                         /*tp_setattro*/
-      0,                         /*tp_as_buffer*/
+      0,                        /*ob_size*/
+      "systray.Icon",           /*tp_name*/
+      sizeof(Icon),             /*tp_basicsize*/
+      0,                        /*tp_itemsize*/
+      icon_dealloc,             /*tp_dealloc*/
+      0,                        /*tp_print*/
+      0,                        /*tp_getattr*/
+      0,                        /*tp_setattr*/
+      0,                        /*tp_compare*/
+      0,                        /*tp_repr*/
+      0,                        /*tp_as_number*/
+      0,                        /*tp_as_sequence*/
+      0,                        /*tp_as_mapping*/
+      0,                        /*tp_hash */
+      0,                        /*tp_call*/
+      0,                        /*tp_str*/
+      0,                        /*tp_getattro*/
+      0,                        /*tp_setattro*/
+      0,                        /*tp_as_buffer*/
       Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /*tp_flags*/
-      "EggSysTrayIcon",          /* tp_doc */
-      0,		               /* tp_traverse */
-      0,		               /* tp_clear */
-      0,		               /* tp_richcompare */
-      0,		               /* tp_weaklistoffset */
-      0,		               /* tp_iter */
-      0,		               /* tp_iternext */
+      "EggSysTrayIcon",         /* tp_doc */
+      0,                        /* tp_traverse */
+      0,                        /* tp_clear */
+      0,                        /* tp_richcompare */
+      0,                        /* tp_weaklistoffset */
+      0,                        /* tp_iter */
+      0,                        /* tp_iternext */
       (PyMethodDef*) Icon_methods,             /* tp_methods */
-      0,                         /* tp_members */
-      0,                         /* tp_getset */
-      0,                         /* tp_base */
-      0,                         /* tp_dict */
-      0,                         /* tp_descr_get */
-      0,                         /* tp_descr_set */
-      0,                         /* tp_dictoffset */
-      icon_init,          /* tp_init */
-      PyType_GenericAlloc,       /* tp_alloc */
-      PyType_GenericNew,         /* tp_new */
-      _PyObject_Del,             /* tp_free */
+      0,                        /* tp_members */
+      0,                        /* tp_getset */
+      0,                        /* tp_base */
+      0,                        /* tp_dict */
+      0,                        /* tp_descr_get */
+      0,                        /* tp_descr_set */
+      0,                        /* tp_dictoffset */
+      icon_init,                /* tp_init */
+      PyType_GenericAlloc,      /* tp_alloc */
+      PyType_GenericNew,        /* tp_new */
+      _PyObject_Del,            /* tp_free */
     };
 
-
   PyObject* module;
 
   if(!gdesklets_get_pygobject_type())
@@ -149,6 +150,3 @@ initsystray(void)
   PyObject_SetAttrString(module, "Icon", (PyObject*) &IconType);
 }
 
-
-
-
