@@ -54,6 +54,26 @@ int parse_gdk_window(PyObject *object, gpointer address)
 }
 
 
+int parse_gdk_pixmap(PyObject *object, gpointer address)
+{
+  GdkPixmap **pmap = address;
+
+  if(!pygobject_check(object, gdesklets_get_pygobject_type()))
+    goto err;
+
+  if(!GDK_IS_PIXMAP(pygobject_get(object)))
+    goto err;
+
+  *pmap = GDK_PIXMAP(pygobject_get(object));
+
+  return 1;
+
+ err:
+  PyErr_SetString(PyExc_TypeError, "first parameter must be a GdkPixmap");
+  return 0;
+}
+
+
 int parse_gdk_pixbuf(PyObject *object, gpointer address)
 {
   GdkPixbuf **pixbuf = address;
