@@ -1,4 +1,9 @@
-from tiling import Tiling
+try:
+    from utils.tiling import Tiling
+except ImportError:
+    import sys
+    log("Could not import tiling module!")
+    sys.exit(1)
 
 import gtk
 
